Language enum

Supported languages

Inheritance
Available extensions

Values

ar → const Language

Arabic

const Language('ar', 'العربية')
en → const Language

English

const Language('en', 'English')

Properties

code String
Language code
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
Language name
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCode(String code) Language
Get language from its code

Constants

values → const List<Language>
A constant List of the values in this enum, in order of their declaration.